@@ -1,7 +1,8 @@
 package Catalyst::ActionRole::Guff;
 
 use Moose::Role;
-use namespace::clean -except => [ 'meta' ];
+
+use namespace::autoclean;
 
 after execute => sub {
     my ($self, $controller, $c) = @_;
